@@ -38,7 +38,7 @@ TEST_COVER_RFJA_12_SET_CLOSE = "01 00 00"
 TEST_COVER_RFJA_12_SET_STOP_UP = "05 00 00"
 TEST_COVER_RFJA_12_SET_STOP_DOWN = "03 00 00"
 
-TEST_CLIMATE_RFATV_2_TOPIC_STATE = "inels/status/4254524524/09/4249589"
-TEST_CLIMATE_RFATV_2_TOPIC_CONNECTED = "inels/connected/4254524524/09/4249589"
-TEST_CLIMATE_RFATV_2_STATE_VALUE = b"00\n34\n00\n40\n00\n"
-TEST_CLIMATE_RFATV_2_SET_VALUE = "00 3C 00"
+TEST_WATER_HEATER_RFATV_2_TOPIC_STATE = "inels/status/4254524524/09/4249589"
+TEST_WATER_HEATER_RFATV_2_TOPIC_CONNECTED = "inels/connected/4254524524/09/4249589"
+TEST_WATER_HEATER_RFATV_2_STATE_VALUE = b"00\n34\n00\n40\n00\n"
+TEST_WATER_HEATER_RFATV_2_SET_VALUE = "00 3C 00"
