@@ -10,7 +10,6 @@ from inelsmqtt.util import DeviceValue
 from inelsmqtt.devices import Device, DeviceInfo
 from inelsmqtt.const import (
     BATTERY,
-    CLIMATE,
     COVER,
     MANUFACTURER,
     RFATV_2,
@@ -38,6 +37,7 @@ from inelsmqtt.const import (
     MQTT_PROTOCOL,
     PROTO_5,
     VERSION,
+    WATER_HEATER,
 )
 
 from tests.const import (
@@ -52,9 +52,9 @@ from tests.const import (
     TEST_LIGH_STATE_INELS_VALUE,
     TEST_LIGHT_DIMMABLE_TOPIC_STATE,
     TEST_LIGHT_SET_INELS_VALUE,
-    TEST_CLIMATE_RFATV_2_STATE_VALUE,
-    TEST_CLIMATE_RFATV_2_TOPIC_CONNECTED,
-    TEST_CLIMATE_RFATV_2_TOPIC_STATE,
+    TEST_WATER_HEATER_RFATV_2_STATE_VALUE,
+    TEST_WATER_HEATER_RFATV_2_TOPIC_CONNECTED,
+    TEST_WATER_HEATER_RFATV_2_TOPIC_STATE,
     TEST_SENSOR_TOPIC_STATE,
     TEST_AVAILABILITY_OFF,
     TEST_AVAILABILITY_ON,
@@ -107,7 +107,7 @@ class DeviceTest(TestCase):
             InelsMqtt(config), TEST_COVER_RFJA_12_TOPIC_STATE, "Shutter"
         )
         self.valve = Device(
-            InelsMqtt(config), TEST_CLIMATE_RFATV_2_TOPIC_STATE, "Climate"
+            InelsMqtt(config), TEST_WATER_HEATER_RFATV_2_TOPIC_STATE, "Climate"
         )
 
     def tearDown(self) -> None:
@@ -349,14 +349,14 @@ class DeviceTest(TestCase):
     def test_device_support_climate_initialized(self, mock_message) -> None:
         """Test climate all props. initialization."""
         mock_message.return_value = {
-            TEST_CLIMATE_RFATV_2_TOPIC_STATE: TEST_CLIMATE_RFATV_2_STATE_VALUE,
-            TEST_CLIMATE_RFATV_2_TOPIC_CONNECTED: TEST_AVAILABILITY_ON,
+            TEST_WATER_HEATER_RFATV_2_TOPIC_STATE: TEST_WATER_HEATER_RFATV_2_STATE_VALUE,
+            TEST_WATER_HEATER_RFATV_2_TOPIC_CONNECTED: TEST_AVAILABILITY_ON,
         }
 
         self.valve.get_value()
 
         self.assertTrue(self.valve.is_available)
-        self.assertEqual(self.valve.device_type, CLIMATE)
+        self.assertEqual(self.valve.device_type, WATER_HEATER)
         self.assertEqual(self.valve.inels_type, RFATV_2)
         self.assertEqual(self.valve.state.current, 26.0)
         self.assertEqual(self.valve.state.required, 32.0)
@@ -366,7 +366,7 @@ class DeviceTest(TestCase):
     def test_device_set_climate_valve_value(self, mock_message, mock_publish) -> None:
         """Test valve value."""
         mock_message.return_value = {
-            TEST_CLIMATE_RFATV_2_TOPIC_STATE: TEST_CLIMATE_RFATV_2_STATE_VALUE
+            TEST_WATER_HEATER_RFATV_2_TOPIC_STATE: TEST_WATER_HEATER_RFATV_2_STATE_VALUE
         }
         mock_publish.return_value = True
 
